<?php
/*
Plugin Name:  Elementor Breadcrumb Widget
Plugin URI:   https://www.limaweb.nl/downloads/
Description:  Adds a breadcrumb widget to Elementor.
Version:      1.0
Author:       LimaWeb
Author URI:   https://www.limaweb.nl/
License:      GPL2
License URI:  https://www.gnu.org/licenses/gpl-2.0.html
*/


if (! defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

// Ensuring Elementor is activated before proceeding
function check_if_elementor_activated()
{
    if (! did_action('elementor/loaded')) {
        add_action('admin_notices', function () {
            echo '<div class="notice notice-warning is-dismissible"><p>The Elementor Breadcrumb Widget plugin requires Elementor to be installed and activated.</p></div>';
        });
        return;
    }
}
add_action('plugins_loaded', 'check_if_elementor_activated');

// Register the breadcrumb widget for Elementor
function register_breadcrumb_widget($widgets_manager)
{
    require_once(__DIR__ . '/breadcrumb-widget.php');
    \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new \Elementor_Breadcrumb_Widget());
}
add_action('elementor/widgets/register', 'register_breadcrumb_widget');

// Breadcrumb shortcode function definition
function breadcrumb_shortcode($atts)
{
    $atts = shortcode_atts(
        array(
            'delimiter' => '&gt;', // HTML entity for '>'
        ),
        $atts,
        'breadcrumb'
    );

    global $post;
    $breadcrumb = '<a href="' . home_url() . '">' . __('Home', 'elementor-breadcrumb') . '</a>';
    $delimiter = ' ' . esc_html($atts['delimiter']) . ' ';

    if (is_category()) {
        $category = get_category(get_query_var('cat'));
        if ($category->parent != 0) {
            $parent_category = get_category($category->parent);
            $breadcrumb .= $delimiter . get_category_parents($parent_category, TRUE, $delimiter);
        }
        $breadcrumb .= '<span>' . single_cat_title('', false) . '</span>';
    } elseif (is_single()) {
        $categories = get_the_category();
        if (!empty($categories)) {
            $category = current($categories);
            $breadcrumb .= get_category_parents($category, TRUE, $delimiter);
        }
        $breadcrumb .= '<span>' . get_the_title() . '</span>';
    } elseif (is_page() && !is_front_page()) {
        if ($post->post_parent) {
            $parent_id  = $post->post_parent;
            $crumbs = array();
            while ($parent_id) {
                $page = get_page($parent_id);
                $crumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
                $parent_id  = $page->post_parent;
            }
            $crumbs = array_reverse($crumbs);
            foreach ($crumbs as $crumb) {
                $breadcrumb .= $delimiter . $crumb;
            }
        }
        $breadcrumb .= $delimiter . '<span>' . get_the_title() . '</span>';
    } elseif (is_tag()) {
        $breadcrumb .= $delimiter . '<span>' . single_tag_title('', false) . '</span>';
    } elseif (is_day()) {
        $breadcrumb .= $delimiter . '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a>';
        $breadcrumb .= $delimiter . '<a href="' . get_month_link(get_the_time('Y'), get_the_time('m')) . '">' . get_the_time('F') . '</a>';
        $breadcrumb .= $delimiter . '<span>' . get_the_time('d') . '</span>';
    } elseif (is_month()) {
        $breadcrumb .= $delimiter . '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a>';
        $breadcrumb .= $delimiter . '<span>' . get_the_time('F') . '</span>';
    } elseif (is_year()) {
        $breadcrumb .= $delimiter . '<span>' . get_the_time('Y') . '</span>';
    } elseif (is_author()) {
        $breadcrumb .= $delimiter . '<span>' . get_the_author() . '</span>';
    } elseif (is_search()) {
        $breadcrumb .= $delimiter . '<span>' . __('Search results for: ', 'elementor-breadcrumb') . get_search_query() . '</span>';
    } elseif (is_404()) {
        $breadcrumb .= $delimiter . '<span>' . __('404 Error: Page Not Found', 'elementor-breadcrumb') . '</span>';
    }

    return '<nav class="breadcrumb">' . $breadcrumb . '</nav>';
}
add_shortcode('breadcrumb', 'breadcrumb_shortcode');
